@@ -1,3 +1,4 @@
+// clang-format off
 /*
  *  This file is part of KDiff3.
  *
@@ -5,10 +6,12 @@
  * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
  * SPDX-License-Identifier: GPL-2.0-or-later
 */
+// clang-format on
 #include "Overview.h"
 
 #include "diff.h"
 #include "kdiff3.h"
+#include "MergeEditLine.h"
 #include "options.h"
 
 #include <algorithm> // for max
@@ -125,15 +128,18 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
     {
         const Diff3Line& d3l = *i;
         int y = h * (line + 1) / nofLines;
+        MergeLine lMergeLine;
         e_MergeDetails md;
         bool bConflict;
         bool bLineRemoved;
-        e_SrcSelector src;
-        d3l.mergeOneLine(md, bConflict, bLineRemoved, src, !KDiff3App::isTripleDiff());
 
-        QColor c = m_pOptions->m_bgColor;
+        lMergeLine.mergeOneLine(d3l, bLineRemoved, !KDiff3App::isTripleDiff());
+        md = lMergeLine.details();
+        bConflict = lMergeLine.isConflict();
+
+        QColor c = m_pOptions->backgroundColor();
         bool bWhiteSpaceChange = false;
-        //if( bConflict )  c=m_pOptions->m_colorForConflict;
+        //if( bConflict )  c=m_pOptions->conflictColor();
         //else
         switch(eOverviewMode)
         {
@@ -142,13 +148,13 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                 {
                     case e_MergeDetails::eDefault:
                     case e_MergeDetails::eNoChange:
-                        c = m_pOptions->m_bgColor;
+                        c = m_pOptions->backgroundColor();
                         break;
 
                     case e_MergeDetails::eBAdded:
                     case e_MergeDetails::eBDeleted:
                     case e_MergeDetails::eBChanged:
-                        c = bConflict ? m_pOptions->m_colorForConflict : m_pOptions->m_colorB;
+                        c = bConflict ? m_pOptions->conflictColor() : m_pOptions->bColor();
                         bWhiteSpaceChange = d3l.isEqualAB() || (d3l.isWhiteLine(e_SrcSelector::A) && d3l.isWhiteLine(e_SrcSelector::B));
                         break;
 
@@ -156,7 +162,7 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                     case e_MergeDetails::eCDeleted:
                     case e_MergeDetails::eCChanged:
                         bWhiteSpaceChange = d3l.isEqualAC() || (d3l.isWhiteLine(e_SrcSelector::A) && d3l.isWhiteLine(e_SrcSelector::C));
-                        c = bConflict ? m_pOptions->m_colorForConflict : m_pOptions->m_colorC;
+                        c = bConflict ? m_pOptions->conflictColor() : m_pOptions->cColor();
                         break;
 
                     case e_MergeDetails::eBCChanged:         // conflict
@@ -166,7 +172,7 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                     case e_MergeDetails::eCChanged_BDeleted: // conflict
                     case e_MergeDetails::eBCAdded:           // conflict
                     case e_MergeDetails::eBCAddedAndEqual:   // possible conflict
-                        c = m_pOptions->m_colorForConflict;
+                        c = m_pOptions->conflictColor();
                         break;
                 }
                 break;
@@ -180,7 +186,7 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                     case e_MergeDetails::eCChanged:
                         break;
                     default:
-                        c = m_pOptions->m_colorForConflict;
+                        c = m_pOptions->conflictColor();
                         bWhiteSpaceChange = d3l.isEqualAB() || (d3l.isWhiteLine(e_SrcSelector::A) && d3l.isWhiteLine(e_SrcSelector::B));
                         break;
                 }
@@ -195,7 +201,7 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                     case e_MergeDetails::eBChanged:
                         break;
                     default:
-                        c = m_pOptions->m_colorForConflict;
+                        c = m_pOptions->conflictColor();
                         bWhiteSpaceChange = d3l.isEqualAC() || (d3l.isWhiteLine(e_SrcSelector::A) && d3l.isWhiteLine(e_SrcSelector::C));
                         break;
                 }
@@ -210,7 +216,7 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
                     case e_MergeDetails::eBCAddedAndEqual:
                         break;
                     default:
-                        c = m_pOptions->m_colorForConflict;
+                        c = m_pOptions->conflictColor();
                         bWhiteSpaceChange = d3l.isEqualBC() || (d3l.isWhiteLine(e_SrcSelector::B) && d3l.isWhiteLine(e_SrcSelector::C));
                         break;
                 }
@@ -224,13 +230,13 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
         {
             if(!d3l.getLineA().isValid() && d3l.getLineB().isValid())
             {
-                c = m_pOptions->m_colorA;
+                c = m_pOptions->aColor();
                 x2 = w / 2;
                 w2 = x2;
             }
             if(d3l.getLineA().isValid() && !d3l.getLineB().isValid())
             {
-                c = m_pOptions->m_colorB;
+                c = m_pOptions->bColor();
                 w2 = w / 2;
             }
         }
@@ -238,12 +244,12 @@ void Overview::drawColumn(QPainter& p, e_OverviewMode eOverviewMode, int x, int
         if(!bWhiteSpaceChange || m_pOptions->m_bShowWhiteSpace)
         {
             // Make sure that lines with conflict are not overwritten.
-            if(c == m_pOptions->m_colorForConflict)
+            if(c == m_pOptions->conflictColor())
             {
                 p.fillRect(x2 + 1, oldY, w2, std::max(1, y - oldY), bWhiteSpaceChange ? QBrush(c, Qt::Dense4Pattern) : QBrush(c));
                 oldConflictY = oldY;
             }
-            else if(c != m_pOptions->m_bgColor && oldY > oldConflictY)
+            else if(c != m_pOptions->backgroundColor() && oldY > oldConflictY)
             {
                 p.fillRect(x2 + 1, oldY, w2, std::max(1, y - oldY), bWhiteSpaceChange ? QBrush(c, Qt::Dense4Pattern) : QBrush(c));
             }
@@ -283,7 +289,7 @@ void Overview::paintEvent(QPaintEvent*)
         m_pixmap.setDevicePixelRatio(dpr);
 
         QPainter p(&m_pixmap);
-        p.fillRect(rect(), m_pOptions->m_bgColor);
+        p.fillRect(rect(), m_pOptions->backgroundColor());
 
         if(!KDiff3App::isTripleDiff() || mOverviewMode == e_OverviewMode::eOMNormal)
         {
