@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -62,13 +63,17 @@ class RecalcWordWrapRunnable : public QRunnable
 {
   private:
     static QAtomicInt s_runnableCount;
-    DiffTextWindow* m_pDTW;
+
+    std::shared_ptr<DiffTextWindow> m_pDTW = nullptr;
     int m_visibleTextWidth;
     QtSizeType m_cacheIdx;
 
+    //Only way to be thread-safe. Globals are inheriently prone to tare down timing issues.
+    std::shared_ptr<ProgressDialog> progressDialog = g_pProgressDialog;
+
   public:
     static QAtomicInt s_maxNofRunnables;
-    RecalcWordWrapRunnable(DiffTextWindow* p, int visibleTextWidth, QtSizeType cacheIdx)
+    RecalcWordWrapRunnable(std::shared_ptr<DiffTextWindow> p, int visibleTextWidth, QtSizeType cacheIdx)
         : m_pDTW(p), m_visibleTextWidth(visibleTextWidth), m_cacheIdx(cacheIdx)
     {
         setAutoDelete(true);
@@ -78,7 +83,7 @@ class RecalcWordWrapRunnable : public QRunnable
     {
         m_pDTW->recalcWordWrapHelper(0, m_visibleTextWidth, m_cacheIdx);
         int newValue = s_runnableCount.fetchAndAddOrdered(-1) - 1;
-        g_pProgressDialog->setCurrent(s_maxNofRunnables - getAtomic(s_runnableCount));
+        progressDialog->setCurrent(s_maxNofRunnables - s_runnableCount.loadRelaxed());
         if(newValue == 0)
         {
             Q_EMIT m_pDTW->finishRecalcWordWrap(m_visibleTextWidth);
@@ -108,7 +113,7 @@ class WrapLineCacheData
 class DiffTextWindowData
 {
   public:
-    explicit DiffTextWindowData(DiffTextWindow* p)
+    explicit DiffTextWindowData(QPointer<DiffTextWindow> p)
     {
         m_pDiffTextWindow = p;
 #if defined(Q_OS_WIN)
@@ -146,7 +151,7 @@ class DiffTextWindowData
   private:
     //TODO: Remove friend classes after creating accessors. Please don't add new classes here
     friend DiffTextWindow;
-    DiffTextWindow* m_pDiffTextWindow;
+    QPointer<DiffTextWindow> m_pDiffTextWindow;
     QTextCodec* m_pTextCodec = nullptr;
     e_LineEndStyle m_eLineEndStyle;
 
@@ -548,7 +553,7 @@ void DiffTextWindow::showStatusLine(const LineRef lineFromPos)
 
     if(d->getDiff3LineVector() != nullptr && d3lIdx >= 0 && d3lIdx < (int)d->getDiff3LineVector()->size())
     {
-        std::shared_ptr<const Diff3Line> pD3l = (*d->getDiff3LineVector())[d3lIdx];
+        const Diff3Line* pD3l = (*d->getDiff3LineVector())[d3lIdx];
         if(pD3l != nullptr)
         {
             LineRef actualLine = pD3l->getLineInFile(d->m_winIdx);
@@ -1238,7 +1243,7 @@ void DiffTextWindowData::draw(RLPainter& p, const QRect& invalidRect, const int
     {
         int wrapLineOffset = 0;
         int wrapLineLength = 0;
-        std::shared_ptr<const Diff3Line> d3l = nullptr;
+        const Diff3Line* d3l = nullptr;
         bool bWrapLine = false;
         if(m_bWordWrap)
         {
@@ -1283,7 +1288,7 @@ QString DiffTextWindowData::getString(LineIndex d3lIdx)
     if(m_pLineData == nullptr || m_pLineData->empty() || d3lIdx < 0 || d3lIdx >= mDiff3LineVector->size())
         return QString();
 
-    std::shared_ptr<const Diff3Line> d3l = (*mDiff3LineVector)[d3lIdx];
+    const Diff3Line* d3l = (*mDiff3LineVector)[d3lIdx];
     const LineRef lineIdx = d3l->getLineIndex(m_winIdx);
 
     if(!lineIdx.isValid())
@@ -1352,7 +1357,7 @@ QString DiffTextWindow::getSelection() const
     int vectorSize = d->m_bWordWrap ? d->m_diff3WrapLineVector.size() : d->getDiff3LineVector()->size();
     for(it = 0; it < vectorSize; ++it)
     {
-        std::shared_ptr<const Diff3Line> d3l = d->m_bWordWrap ? d->m_diff3WrapLineVector[it].pD3L : (*d->getDiff3LineVector())[it];
+        const Diff3Line* d3l = d->m_bWordWrap ? d->m_diff3WrapLineVector[it].pD3L : (*d->getDiff3LineVector())[it];
 
         assert(d->m_winIdx >= e_SrcSelector::A && d->m_winIdx <= e_SrcSelector::C);
 
@@ -1478,7 +1483,7 @@ void DiffTextWindow::setSelection(LineRef firstLine, int startPos, LineRef lastL
     {
         lastLine = getNofLines() - 1;
 
-        std::shared_ptr<const Diff3Line> d3l = (*d->getDiff3LineVector())[convertLineToDiff3LineIdx(lastLine)];
+        const Diff3Line* d3l = (*d->getDiff3LineVector())[convertLineToDiff3LineIdx(lastLine)];
         LineRef line;
         if(d->m_winIdx == e_SrcSelector::A) line = d3l->getLineA();
         if(d->m_winIdx == e_SrcSelector::B) line = d3l->getLineB();
@@ -1539,7 +1544,7 @@ int DiffTextWindowData::convertLineOnScreenToLineInSource(int lineOnScreen, e_Co
         if(coordType == eD3LLineCoords) return d3lIdx;
         while(!line.isValid() && d3lIdx < mDiff3LineVector->size() && d3lIdx >= 0)
         {
-            std::shared_ptr<const Diff3Line> d3l = (*mDiff3LineVector)[d3lIdx];
+            const Diff3Line* d3l = (*mDiff3LineVector)[d3lIdx];
             if(m_winIdx == e_SrcSelector::A) line = d3l->getLineA();
             if(m_winIdx == e_SrcSelector::B) line = d3l->getLineB();
             if(m_winIdx == e_SrcSelector::C) line = d3l->getLineC();
@@ -1631,7 +1636,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
             for(QtSizeType i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
             {
                 d->m_wrapLineCacheList.append(QVector<WrapLineCacheData>());
-                s_runnables.push_back(new RecalcWordWrapRunnable(this, visibleTextWidth, j));
+                s_runnables.push_back(new RecalcWordWrapRunnable(shared_from_this(), visibleTextWidth, j));
             }
         }
         else
@@ -1649,7 +1654,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
             setUpdatesEnabled(false);
             for(int i = 0, j = 0; i < d->getDiff3LineVector()->size(); i += s_linesPerRunnable, ++j)
             {
-                s_runnables.push_back(new RecalcWordWrapRunnable(this, visibleTextWidth, j));
+                s_runnables.push_back(new RecalcWordWrapRunnable(shared_from_this(), visibleTextWidth, j));
             }
         }
         else
@@ -1658,7 +1663,7 @@ void DiffTextWindow::recalcWordWrap(bool bWordWrap, QtSizeType wrapLineVectorSiz
         }
     }
 }
-//FIXME: incoming visableTextWidth used as de-facto bool.
+
 void DiffTextWindow::recalcWordWrapHelper(QtSizeType wrapLineVectorSize, int visibleTextWidth, QtSizeType cacheListIdx)
 {
     if(d->m_bWordWrap)
@@ -1850,7 +1855,7 @@ class DiffTextWindowFrameData
 
   private:
     friend DiffTextWindowFrame;
-    DiffTextWindow* m_pDiffTextWindow;
+    std::shared_ptr<DiffTextWindow> m_pDiffTextWindow;
     FileNameLineEdit* m_pFileSelection;
     QPushButton* m_pBrowseButton;
     QSharedPointer<Options> m_pOptions;
@@ -1873,7 +1878,7 @@ DiffTextWindowFrame::DiffTextWindowFrame(QWidget* pParent, const QSharedPointer<
     chk_connect(d->getBrowseButton(), &QPushButton::clicked, this, &DiffTextWindowFrame::slotBrowseButtonClicked);
     chk_connect(d->getFileSelectionField(), &QLineEdit::returnPressed, this, &DiffTextWindowFrame::slotReturnPressed);
 
-    d->m_pDiffTextWindow = new DiffTextWindow(this, pOptions, winIdx, app);
+    d->m_pDiffTextWindow = std::make_shared<DiffTextWindow>(this, pOptions, winIdx, app);
     d->m_pDiffTextWindow->setSourceData(psd);
     QVBoxLayout* pVTopLayout = new QVBoxLayout(const_cast<QWidget*>(d->getTopLineWidget()));
     pVTopLayout->setContentsMargins(2, 2, 2, 2);
@@ -1908,7 +1913,7 @@ DiffTextWindowFrame::DiffTextWindowFrame(QWidget* pParent, const QSharedPointer<
     pVL->setContentsMargins(0, 0, 0, 0);
     pVL->setSpacing(0);
     pVL->addWidget(const_cast<QWidget*>(d->getTopLineWidget()), 0);
-    pVL->addWidget(d->m_pDiffTextWindow, 1);
+    pVL->addWidget(d->m_pDiffTextWindow.get(), 1);
 
     d->m_pDiffTextWindow->installEventFilter(this);
     d->m_pFileSelection->installEventFilter(this);
@@ -1916,11 +1921,19 @@ DiffTextWindowFrame::DiffTextWindowFrame(QWidget* pParent, const QSharedPointer<
     init();
 }
 
-DiffTextWindowFrame::~DiffTextWindowFrame() = default;
+DiffTextWindowFrame::~DiffTextWindowFrame()
+{
+    /*
+        Qt uses parent for memory management and event hierachy this is the only way to
+        by pass auto cleanup. That is needed thanks to the wordwrap helper threads using
+        DiffTextWindow pointers which must be std::shared_ptr.
+    */
+    getDiffTextWindow()->setParent(nullptr);
+}
 
 void DiffTextWindowFrame::init()
 {
-    DiffTextWindow* pDTW = d->m_pDiffTextWindow;
+    std::shared_ptr<DiffTextWindow> pDTW = d->m_pDiffTextWindow;
     if(pDTW)
     {
         QString s = QDir::toNativeSeparators(pDTW->getFileName());
@@ -1945,7 +1958,7 @@ LineRef DiffTextWindow::calcTopLineInFile(const LineRef firstLine)
     LineRef currentLine;
     for(QtSizeType i = convertLineToDiff3LineIdx(firstLine); i < d->getDiff3LineVector()->size(); ++i)
     {
-        std::shared_ptr<const Diff3Line> d3l = (*d->getDiff3LineVector())[i];
+        const Diff3Line* d3l = (*d->getDiff3LineVector())[i];
         currentLine = d3l->getLineInFile(d->m_winIdx);
         if(currentLine.isValid()) break;
     }
@@ -1954,7 +1967,7 @@ LineRef DiffTextWindow::calcTopLineInFile(const LineRef firstLine)
 
 void DiffTextWindowFrame::setFirstLine(QtNumberType firstLine)
 {
-    DiffTextWindow* pDTW = d->m_pDiffTextWindow;
+    std::shared_ptr<DiffTextWindow> pDTW = d->m_pDiffTextWindow;
     if(pDTW && pDTW->getDiff3LineVector())
     {
         QString s = i18n("Top line");
@@ -1975,7 +1988,7 @@ void DiffTextWindowFrame::setFirstLine(QtNumberType firstLine)
     }
 }
 
-DiffTextWindow* DiffTextWindowFrame::getDiffTextWindow()
+std::shared_ptr<DiffTextWindow> DiffTextWindowFrame::getDiffTextWindow()
 {
     return d->m_pDiffTextWindow;
 }
@@ -2013,7 +2026,7 @@ bool DiffTextWindowFrame::eventFilter(QObject* o, QEvent* e)
 
 void DiffTextWindowFrame::slotReturnPressed()
 {
-    DiffTextWindow* pDTW = d->m_pDiffTextWindow;
+    std::shared_ptr<DiffTextWindow> pDTW = d->m_pDiffTextWindow;
     if(pDTW->getFileName() != d->m_pFileSelection->text())
     {
         Q_EMIT fileNameChanged(d->m_pFileSelection->text(), pDTW->getWindowIndex());
@@ -2027,7 +2040,7 @@ void DiffTextWindowFrame::slotBrowseButtonClicked()
     QUrl newURL = QFileDialog::getOpenFileUrl(this, i18n("Open File"), QUrl::fromUserInput(current, QString(), QUrl::AssumeLocalFile));
     if(!newURL.isEmpty())
     {
-        DiffTextWindow* pDTW = d->m_pDiffTextWindow;
+        std::shared_ptr<DiffTextWindow> pDTW = d->m_pDiffTextWindow;
         Q_EMIT fileNameChanged(newURL.url(), pDTW->getWindowIndex());
     }
 }
