@@ -154,7 +154,7 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
     // ProgressProxy will otherwise emit no-ops to disconnected boost signals.
     if(g_pProgressDialog == nullptr)
     {
-        g_pProgressDialog = new ProgressDialog(this, statusBar());
+        g_pProgressDialog = std::make_shared<ProgressDialog>(this, statusBar());
         g_pProgressDialog->setStayHidden(true);
     }
 
@@ -537,11 +537,8 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
 
     if(bSuccess && m_bAutoMode) return;
     if(m_bAutoMode && !isPart())
-    {
         showMainWindow();
-        //Fire wordwrap recalc signal bypassed during auto-merge pass.
-        QMetaObject::invokeMethod(this, &KDiff3App::postRecalcWordWrap, Qt::QueuedConnection);
-    }
+
     m_bAutoMode = false;
 
     if(statusBar() != nullptr)
@@ -583,7 +580,13 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
 
 KDiff3App::~KDiff3App()
 {
-    // Prevent spurious focus change signals from Qt from being picked up by KDiff3App during distruction.
+    /*
+        Qt uses parent for memory management and event hierachy this is the only way to
+        by pass auto cleanup. That is needed thanks to the wordwrap helper threads using
+        DiffTextWindow pointers which must be std::shared_ptr.
+    */
+    g_pProgressDialog->setParent(nullptr);
+    // Prevent spurious focus change signals from Qt from being picked up by KDiff3App during destruction.
     QObject::disconnect(qApp, &QApplication::focusChanged, this, &KDiff3App::slotFocusChanged);
 };
 
@@ -998,6 +1001,8 @@ void KDiff3App::slotFilePrint()
         {
             bPrintCurrentPage = true;
             totalNofPages = 1;
+            // Detect the first visible line in the window.
+            line = m_pDiffTextWindow1->convertDiff3LineIdxToLine(currentFirstD3LIdx);
         }
         else if(printer.printRange() == QPrinter::Selection)
         {
@@ -1023,19 +1028,14 @@ void KDiff3App::slotFilePrint()
                 printer.abort();
                 break;
             }
-            if(!bPrintSelection) {
+            if(!bPrintSelection && !bPrintCurrentPage)
+            {
                 if(pageListIt == pageList.end())
                     break;
                 page = *pageListIt;
                 line = (page - 1) * linesPerPage;
-
-                if(bPrintCurrentPage)
-                {
-                    // Detect the first visible line in the window.
-                    line = m_pDiffTextWindow1->convertDiff3LineIdxToLine(currentFirstD3LIdx);
-                }
             }
-            else
+            else if(bPrintSelection)
             {
                 if(line >= selectionEndLine) {
                     break;
